#
# spec file for package mokutil
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mokutil
Version:        0.3.0
Release:        5.5
Summary:        Tools for manipulating machine owner keys
License:        GPL-3.0
Group:          Productivity/Security
Url:            https://github.com/lcp/mokutil
Source:         %{name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM mokutil-fix-overflow.patch glin@suse.com -- Fix the potential buffer overflow
Patch1:         mokutil-fix-overflow.patch
# PATCH-FIX-UPSTREAM mokutil-fshort-wchar.patch glin@suse.com -- Add "-fshort-wchar" to make sure the UEFI strings are UCS-2 encoding
Patch2:         mokutil-fshort-wchar.patch
# PATCH-FIX-UPSTREAM mokutil-set-efi-variable-file-mode.patch glin@suse.com -- Be explicit about file modes in all cases
Patch3:         mokutil-set-efi-variable-file-mode.patch
# PATCH-FIX-UPSTREAM mokutil-constify-efi-guid.patch glin@suse.com -- Make all efi_guild_t variables const
Patch4:         mokutil-constify-efi-guid.patch
# OPENSUSE ONLY
# PATCH-FIX-OPENSUSE mokutil-support-revoke-builtin-cert.patch glin@suse.com -- Add an option to revoke the built-in certificate
Patch100:       mokutil-support-revoke-builtin-cert.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  efivar-devel >= 0.12
BuildRequires:  libopenssl-devel >= 0.9.8
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  x86_64

%description
This program provides the means to enroll and erase the machine owner
keys (MOK) stored in the database of shim.



Authors:
--------
    Gary Lin <glin@suse.com>

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch100 -p1

%build
autoreconf
%configure
make

%install
%makeinstall

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc COPYING
%{_bindir}/mokutil
%{_mandir}/man?/*

%changelog
* Wed Jul 13 2016 glin@suse.com
- Patches for efivar 0.24
  + Add mokutil-set-efi-variable-file-mode.patch to set the file
    mode explicitly.
  + Add mokutil-constify-efi-guid.patch to make all efi_guild_t
    variables const.
  + Refresh mokutil-support-revoke-builtin-cert.patch for the
    change of efi_set_variable()
* Tue Jun 30 2015 glin@suse.com
- Add mokutil-fshort-wchar.patch to make sure the UEFI strings are
  UCS-2 encoding.
* Tue Nov  4 2014 glin@suse.com
- Update to 0.3.0
- Add mokutil-fix-overflow.patch to fix the buffer overflow
- Drop upstreamed patches
  + mokutil-upstream-fixes.patch
  + mokutil-mokx-support.patch
  + mokutil-check-corrupted-key-list.patch
  + mokutil-check-secure-boot-support.patch
  + mokutil-clean-request.patch
  + mokutil-fix-hash-file-read.patch
  + mokutil-fix-hash-list-size.patch
  + mokutil-more-details-for-skipped-keys.patch
  + mokutil-no-invalid-x509.patch
- Refresh mokutil-support-revoke-builtin-cert.patch
* Wed Apr 16 2014 glin@suse.com
- Add mokutil-fix-hash-file-read.patch to fix the error handling of
  reading a hash file
* Thu Apr 10 2014 glin@suse.com
- Add mokutil-check-corrupted-key-list.patch to check whether the
  key list is corrupted or not
- Add mokutil-no-invalid-x509.patch to avoid importing an invalid
  x509 certificate
* Mon Mar 24 2014 glin@suse.com
- Add mokutil-more-details-for-skipped-keys.patch to show the
  reason to skip the key
- Add mokutil-check-secure-boot-support.patch to check whether the
  system supports Secure Boot or not
* Fri Feb 21 2014 glin@suse.com
- Add mokutil-support-revoke-builtin-cert.patch to add an option to
  revoke the built-in certificate in shim
* Wed Feb 12 2014 glin@suse.com
- Add mokutil-fix-hash-list-size.patch to update the list size
  after merging or deleting a hash
- Add mokutil-clean-request.patch to clean the request if all keys
  are removed
* Wed Jan 22 2014 glin@suse.com
- Update mokutil-mokx-support.patch to fix the test-key request
  check
* Thu Dec  5 2013 glin@suse.com
- Add mokutil-upstream-fixes.patch to include upstream fixes for
  db signature check, gcc warnings, and error handling
- Add mokutil-mokx-support.patch to support the MOK blacklist
  (FATE#316531)
* Thu Jul 25 2013 glin@suse.com
- Update to 0.2.0
  + Generate the password hash with crypt() by default instead of
    the original sha256 password hash
  + Add an option to import the root password hash
  + Amend error messages, help, and man page
- Drop upstreamed patches
  + mokutil-lcrypt-ldflag.patch
  + mokutil-probe-secure-boot-state.patch
  + mokutil-allow-password-from-pipe.patch
  + mokutil-bnc809703-check-pending-request.patch
  + mokutil-support-delete-keys.patch
  + mokutil-support-crypt-hash-methods.patch
  + mokutil-update-man-page.patch
  + mokutil-bnc809215-improve-wording.patch
  + mokutil-support-new-pw-hash.patch
  + mokutil-no-duplicate-keys-imported.patch
* Tue Apr  2 2013 glin@suse.com
- Add mokutil-bnc809215-improve-wording.patch to make the messages
  understandable (bnc#809215)
- Add mokutil-bnc809703-check-pending-request.patch to remove the
  key from the pending request if necessary (bnc#809703)
* Wed Jan 30 2013 glin@suse.com
- Merge patches for FATE#314506
  + Add mokutil-support-crypt-hash-methods.patch to support the
    password hashes from /etc/shadow
  + Add mokutil-update-man-page.patch to update man page for the
    new added options
- Add mokutil-lcrypt-ldflag.patch to correct LDFLAGS
* Fri Jan 18 2013 glin@suse.com
- Update mokutil-support-new-pw-hash.patch to extend the password
  hash format
* Wed Jan 16 2013 glin@suse.com
- Merge patches for FATE#314506
  + Add mokutil-support-delete-keys.patch to delete specific keys
  + Add mokutil-support-new-pw-hash.patch to support the new
    password format
  + Add mokutil-allow-password-from-pipe.patch to allow the
    password to be generated in a script and be sent through
    pipeline
- Install COPYING
* Tue Dec 11 2012 glin@suse.com
- Add mokutil-probe-secure-boot-state.patch to probe the state of
  secure boot
- Add mokutil-no-duplicate-keys-imported.patch to avoid importing
  duplicate keys
* Wed Nov  7 2012 glin@suse.com
- Add new package mokutil-0.1.0 (FATE#314510)
